
<!-- README.md is generated from README.Rmd. Please edit that file -->

# pyks

<!-- badges: start -->

[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/version.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/latest_release_date.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/platforms.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/license.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/downloads.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/installer/conda.svg)](https://conda.anaconda.org/jiaxiangbu)
[![DOI](https://zenodo.org/badge/197245838.svg)](https://zenodo.org/badge/latestdoi/197245838)
[![PyPI
version](https://badge.fury.io/py/pyks.svg)](https://badge.fury.io/py/pyks)
<!-- badges: end -->

The goal of `pyks` is to help do calculation KS statistic for a model.
The R version [rawKS](https://github.com/JiaxiangBU/rawKS) is hosted
from GitHub.

## Installation

You can install the released version of `pyks` from [Anaconda
Cloud](https://anaconda.org/JiaxiangBU/pyks) with:

``` conda
conda install -c jiaxiangbu pyks 
```

or the released version of `pyks` from [Python Package
Index](https://pypi.org/project/pyks/) with:

``` conda
pip install pyks
```

or the development version from [GitHub](https://github.com/)
    with:

``` conda
pip install git+https://github.com/JiaxiangBU/pyks
```

## Examples

1.  [examples1.ipynb](https://nbviewer.jupyter.org/urls/jiaxiangbu.github.io/pyks/examples1.ipynb)
2.  [examples2.ipynb](https://nbviewer.jupyter.org/urls/jiaxiangbu.github.io/pyks/examples2.ipynb)
